#
# Copyright (C) 2024  CZ.NIC, z. s. p. o.
#
# This file is part of FRED.
#
# FRED is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# FRED is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with FRED.  If not, see <https://www.gnu.org/licenses/>.

"""List pagination."""

from typing import Any, Optional

from django.db.models import QuerySet
from ninja import Field, Schema
from ninja.pagination import PaginationBase


class LimitOffsetPagination(PaginationBase):
    """Simple offset + limit pagination."""

    class Input(Schema):
        """Input parameters for pagination."""

        limit: Optional[int] = Field(None, ge=1, description="Maximum number of items to return (unlimited by default)")
        offset: int = Field(0, ge=0, description="Number of items to skip (none by default)")

    def paginate_queryset(self, queryset: QuerySet, pagination: Input, **params: Any) -> Any:
        """Adjust queryset and return response list in required form."""
        index_from = pagination.offset
        index_to = None if pagination.limit is None else pagination.offset + pagination.limit
        return {
            self.items_attribute: queryset[index_from:index_to],
            "count": self._items_count(queryset),
        }
