# Part 2 of adding `uuid` to `paymentimporthistory` - fill UUID

import uuid

from django.db import migrations, transaction


def fill_uuid(apps, schema_editor):  # pragma: no cover
    BATCH_SIZE = 1000
    PaymentImportHistory = apps.get_model("django_pain", "PaymentImportHistory")
    while PaymentImportHistory.objects.filter(uuid__isnull=True).exists():
        with transaction.atomic():
            batch = PaymentImportHistory.objects.filter(uuid__isnull=True).select_for_update()[:BATCH_SIZE]
            for item in batch:
                item.uuid = uuid.uuid4()
            PaymentImportHistory.objects.bulk_update(batch, ["uuid"])


class Migration(migrations.Migration):
    atomic = False

    dependencies = [
        ("django_pain", "0052_payment_import_history_uuid_1"),
    ]

    operations = [
        migrations.RunPython(fill_uuid, reverse_code=migrations.RunPython.noop, elidable=True),
    ]
