# Part 2 of adding `uuid` to `bankaccount` - fill UUID

import uuid

from django.db import migrations


def fill_uuid(apps, schema_editor):  # pragma: no cover
    BankAccount = apps.get_model("django_pain", "BankAccount")
    # Update operation can be carried out at once due to small number of items.
    accounts = BankAccount.objects.filter(uuid__isnull=True).select_for_update()
    for account in accounts:
        account.uuid = uuid.uuid4()
    BankAccount.objects.bulk_update(accounts, ["uuid"])


class Migration(migrations.Migration):
    dependencies = [
        ("django_pain", "0055_bank_account_uuid_1"),
    ]

    operations = [
        migrations.RunPython(fill_uuid, reverse_code=migrations.RunPython.noop, elidable=True),
    ]
