#
# Copyright (C) 2024-2025  CZ.NIC, z. s. p. o.
#
# This file is part of FRED.
#
# FRED is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# FRED is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with FRED.  If not, see <https://www.gnu.org/licenses/>.

"""Tests of FRED gRPC logger utilities."""

from typing import Any, Optional

from django.test import SimpleTestCase
from grill import LogProperty

from django_pain.api.paginate import LimitOffsetPagination
from django_pain.api.schema import ListBankAccountFilter, ListBankAccountOrder
from django_pain.logger import make_log_list_properties


class TestMakeLogListProperties(SimpleTestCase):
    """Test for `make_log_list_properties` function."""

    # Use bank account filtering and ordering schema as an example of the respectice classes.

    def test_make_log_properties(self):
        data: list[tuple[dict[str, Any], dict[str, Any], dict[str, Any], Optional[dict[str, Any]]]] = [
            ({}, {}, {}, None),
            ({"number": "/0300"}, {}, {}, {"filter": LogProperty("", children={"number": "/0300"})}),
            ({}, {"order_by": "+currency"}, {}, {"order_by": "+currency"}),
            ({}, {}, {"offset": 5}, {"page": LogProperty("", children={"offset": "5"})}),
            (
                {"number": "/0300", "name": "income"},
                {"order_by": "+currency"},
                {"offset": 5, "limit": 100},
                {
                    "filter": LogProperty("", children={"number": "/0300", "name": "income"}),
                    "order_by": "+currency",
                    "page": LogProperty("", children={"offset": "5", "limit": "100"}),
                },
            ),
        ]
        for filter, order, page, expected in data:
            with self.subTest(filter=filter, order=order, page=page):
                self.assertEqual(
                    make_log_list_properties(
                        ListBankAccountFilter(**filter),
                        ListBankAccountOrder(**order),
                        LimitOffsetPagination.Input(**page),
                    ),
                    expected,
                )
